Module: Adrift::Pattern::Tags
- Defined in:
- lib/adrift/pattern.rb
Overview
Namespace containing the Tag objects used by Pattern.
They are the building blocks of a Pattern. A Pattern is specialized by specializing the Tags that appear in its string. They need to satisfy the following interface:
[+#label+]
Portion of Pattern#string that is replaced with the returned
value of #specialize.
[#specialize(options)] Value that will replace the label in the Pattern (+options+ are the same passed to Pattern#specialize).
Defined Under Namespace
Classes: Attachment, Basename, Class, ClassName, Extension, Filename, Id, Root, Style, Url