Module: Adrift::Processor
- Defined in:
- lib/adrift/processor.rb
Overview
Namespace containing the procesor objects used by Attachment.
They are used to do whatever it's needed with the attached file, and need to satisfy the following interface:
[#process(attached_file_path, styles)] Do whatever it needs to do. Generally this means creating new files from the attached one, but it can also mean transforming the attached file.
[#processed_files] Hash with the style names as keys and the paths of the processed files as values.
Defined Under Namespace
Classes: Thumbnail